==> anonnet-0.0.1-20011112.tgz: anonnet/src/node.h <==
/* ==========================================================================
 * AnonNet - Anonymous Network Project
 * --------------------------------------------------------------------------
 * Copyright (C) 2001  William Ahern
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 * ==========================================================================
 */

#ifndef _NODE_H
#define _NODE_H 1

#ifndef _MCRYPT_H
#define _MCRYPT_H
#include <mcrypt.h>
#endif

#include "common.h"
#include "thread.h"
#include "crypt.h"


#define NODE_STATE_DEAD		0
#define NODE_STATE_ALIVE	1


typedef struct node {
	thread_t thread; /* inherit thread & object */

	int state;
	int caller_sockd;
	int receiver_sockd;
	int hopid;
	int caller_seq;
	dh_t dh;
	//MCRYPT encrypt_td;
	//MCRYPT decrypt_td;
	cipher_t encrypt_cipher;
	cipher_t decrypt_cipher;
	int hash_type;
	unsigned char hmac_key[64]; /* block size of both SHA1 and Tiger */
} node_t;

node_t *node_create(int);
void node_free(void *);

void node_server_call_back(int);
void node_run(void *);

bool node_link_initiate(node_t *);
bool node_caller_initiate(node_t *);
void node_control_loop(node_t *);
bool node_do_connect(node_t *,unsigned char *);
bool node_link_connect(node_t *,struct sockaddr_in *);


int read_secure_packet(node_t *,unsigned char *);
int write_secure_packet(node_t *,unsigned char *);
int read_packet(int,void *);
int write_packet(int,void *);

#endif /* _NODE_H */

==> anonnet-0.0.1-20021020.tgz: anonnet/src/node.h <==
/* ==========================================================================
 * AnonNet - Anonymous Network Project
 * --------------------------------------------------------------------------
 * Copyright (C) 2001  William Ahern
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 * ==========================================================================
 */

#ifndef _NODE_H
#define _NODE_H 1

#include "common.h"
#include "thread.h"
#include "crypt.h"
#include "link.h"


typedef struct node {
	thread_t thread; /* inherit thread & object */

	link_ctx *east;
	link_ctx *west;
	channel_ctx *channel;
	bool sent;

} node_t;

node_t *node_create(int);
void node_free(void *);

void node_call_back(int);
void node_run(void *);
void node_loop(node_t *);
void node_cntl(node_t *,packet_t *);
void node_close(node_t *);
void node_handle_connect(node_t *);

#endif /* _NODE_H */
